Count16

Trait Count16 

pub trait Count16 {
    // Required method
    fn count_16(&self) -> &Count16Reg;
}
This is a helper trait to make it easier to make most of the TimerCounter impl generic. It doesn’t make too much sense to to try to implement this trait outside of this module.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Count16 for Tc3

Source

impl Count16 for Tc4

Source

impl Count16 for Tc5

Implementors