Increment

Trait Increment 

pub trait Increment: PrivateIncrement { }
Trait mapping each countable type to its successor

This trait maps each countable type to its corresponding successor type. The actual implementation of this trait is contained within PrivateIncrement. Access to PrivateIncrement is restricted, so that safe HAL APIs can be built with it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: PrivateIncrement> Increment for T