UsbBus

Struct UsbBus 

pub struct UsbBus { /* private fields */ }

Implementations

Source

impl UsbBus

pub fn new( _clock: &UsbClock, pm: &mut Pm, dm_pad: impl AnyPin<Id = PA24>, dp_pad: impl AnyPin<Id = PA25>, _usb: Usb, ) -> Self

Source

impl UsbBus

pub fn enable_sof_interrupt(&self)

Enables the Start Of Frame (SOF) interrupt

pub fn disable_sof_interrupt(&self)

Disables the Start Of Frame (SOF) interrupt

pub fn check_sof_interrupt(&self) -> bool

Checks, and clears if set, the Start Of Frame (SOF) interrupt flag

pub fn configure_out_endpoint_multipacket_rx( &self, ep: EndpointAddress, size: u16, ) -> Result<(), UsbError>

Configures the Multi-Packet-Rx feature of the USB peripheral.

This allows for the USB Peripheral to ACK multiple incomming packets in hardware, and then only fire an interrupt once the buffer is full. This will reduce the number of USB interrupts, especially when dealing with BULK endpoints.

The default behaviour of the endpoint is to trigger an interrupt as soon as any amount of data is received (size = 0).

The Buffer size can be configured using the HAL’s feature flags:

Feature flagEndpoint buffer sizeMax number of hardware ACK packets
usb-buffer-1k641
usb-buffer-2k1282
usb-buffer-4k2564
usb-buffer-8k5128
usb-buffer-16k102416

NOTE: Above table assumes a 64 byte packet size (USB FS Standard)

Requirements
  1. size is less than the allocated buffer of the endpoint.
  2. size is a multiple of the endpoints packet size.
  3. The provided ep is an OUT endpoint.
Notes
  • For IN endpoints, multi-packet transfer is automatically handled without any user input.
  • If less than size bytes are received by the endpoint, then it will NOT fire an interrupt.
  • ZLP packets still result in an interrupt being fired, regardless of the endpoints received data length