pub trait InterruptExt: InterruptNumber + Copy {
// Provided methods
unsafe fn enable(self) { ... }
fn disable(self) { ... }
fn is_enabled(self) -> bool { ... }
fn is_pending(self) -> bool { ... }
fn pend(self) { ... }
fn unpend(self) { ... }
fn get_priority(self) -> Priority { ... }
fn set_priority(self, prio: Priority) { ... }
fn set_priority_with_cs(self, _cs: CriticalSection<'_>, prio: Priority) { ... }
}Expand description
An interrupt type that can be configured by the HAL to handle interrupts.
The PAC defined enum-level interrupts implement this trait.
Provided Methods
Sourcefn is_enabled(self) -> bool
fn is_enabled(self) -> bool
Check if interrupt is enabled.
Sourcefn is_pending(self) -> bool
fn is_pending(self) -> bool
Check if interrupt is pending.
Sourcefn get_priority(self) -> Priority
fn get_priority(self) -> Priority
Get the priority of the interrupt.
Sourcefn set_priority(self, prio: Priority)
fn set_priority(self, prio: Priority)
Set the interrupt priority.
Sourcefn set_priority_with_cs(self, _cs: CriticalSection<'_>, prio: Priority)
fn set_priority_with_cs(self, _cs: CriticalSection<'_>, prio: Priority)
Set the interrupt priority with an already-acquired critical section.
Equivalent to set_priority, except you pass a
CriticalSection to prove you’ve already acquired a critical
section. This prevents acquiring another one, which saves code size.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".