pub trait Count16 {
// Required method
fn count_16(&self) -> &Count16Reg;
}Expand description
This is a helper trait to make it easier to make most of the TimerCounter impl generic. It doesn’t make too much sense to to try to implement this trait outside of this module.
Required Methods
fn count_16(&self) -> &Count16Reg
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".