pub trait Decrement: PrivateDecrement { }Expand description
Trait mapping each countable type to its predecessor
This trait maps each countable type to its corresponding predecessor type.
The actual implementation of this trait is contained within
PrivateDecrement. Access to PrivateDecrement is restricted, so that safe
HAL APIs can be built with it.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".